Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(83)

Unified Diff: chrome/browser/password_manager/password_store_consumer.h

Issue 137263007: Move CancelableTaskTracker to //base/task/CancelableTaskTracker. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Move to base/task/cancelable_task_tracker* Created 6 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/password_manager/password_store_consumer.h
diff --git a/chrome/browser/password_manager/password_store_consumer.h b/chrome/browser/password_manager/password_store_consumer.h
index 4ac5f589e59579ee72290bc66f4df4495fe8a173..4d4e8c16da776387ac1ad11f86f5953541ee8151 100644
--- a/chrome/browser/password_manager/password_store_consumer.h
+++ b/chrome/browser/password_manager/password_store_consumer.h
@@ -5,7 +5,7 @@
#ifndef CHROME_BROWSER_PASSWORD_MANAGER_PASSWORD_STORE_CONSUMER_H_
#define CHROME_BROWSER_PASSWORD_MANAGER_PASSWORD_STORE_CONSUMER_H_
-#include "chrome/common/cancelable_task_tracker.h"
+#include "base/task/cancelable_task_tracker.h"
namespace autofill {
struct PasswordForm;
@@ -14,8 +14,8 @@ struct PasswordForm;
// Reads from the PasswordStore are done asynchronously on a separate
// thread. PasswordStoreConsumer provides the virtual callback method, which is
// guaranteed to be executed on this (the UI) thread. It also provides the
// CancelableTaskTracker member, which cancels any outstanding tasks upon
// destruction.
class PasswordStoreConsumer {
public:
PasswordStoreConsumer();
@@ -26,9 +26,9 @@ class PasswordStoreConsumer {
virtual void OnGetPasswordStoreResults(
const std::vector<autofill::PasswordForm*>& results) = 0;
- // The CancelableTaskTracker can be used for cancelling the tasks associated
- // with the consumer.
- CancelableTaskTracker* cancelable_task_tracker() {
+ // The base::CancelableTaskTracker can be used for cancelling the
+ // tasks associated with the consumer.
+ base::CancelableTaskTracker* cancelable_task_tracker() {
return &cancelable_task_tracker_;
}
@@ -40,7 +40,7 @@ class PasswordStoreConsumer {
virtual ~PasswordStoreConsumer();
private:
- CancelableTaskTracker cancelable_task_tracker_;
+ base::CancelableTaskTracker cancelable_task_tracker_;
base::WeakPtrFactory<PasswordStoreConsumer> weak_ptr_factory_;
};
« no previous file with comments | « chrome/browser/notifications/message_center_settings_controller.cc ('k') | chrome/browser/sessions/base_session_service.h » ('j') | no next file with comments »
@@ -14,8 +14,8 @@ struct PasswordForm;
// thread. PasswordStoreConsumer provides the virtual callback method, which is
// guaranteed to be executed on this (the UI) thread. It also provides the
-// CancelableTaskTracker member, which cancels any outstanding tasks upon
-// destruction.
+// base::CancelableTaskTracker member, which cancels any outstanding
+// tasks upon destruction.
class PasswordStoreConsumer {
public:

Powered by Google App Engine
This is Rietveld 408576698